# $Id: Title.pm,v 1.1 2002/02/08 13:02:27 joern Exp $

#-----------------------------------------------------------------------
# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
# 
# This module is part of Video::DVDRip, which is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#-----------------------------------------------------------------------

package Video::DVDRip::GUI::Cluster::Title;

use base Video::DVDRip::GUI::Window;

use strict;
use Carp;

sub multi_instance_window { 1 }

sub gtk_widgets			{ shift->{gtk_widgets}			}
sub set_gtk_widgets		{ shift->{gtk_widgets}		= $_[1] }

sub master			{ shift->{master}			}
sub set_master			{ shift->{master}		= $_[1] }

sub title			{ shift->{title}			}
sub set_title			{ shift->{title}		= $_[1] }

sub title_data			{ shift->{title_data}			}
sub set_title_data		{ shift->{title_data}		= $_[1] }

# GUI Stuff ----------------------------------------------------------

sub new {
	my $class = shift;
	my %par = @_;
	my  ($master, $title) =
	@par{'master','title'};
	
	my $self = $class->SUPER::new (@_);

	$self->set_master ($master);
	$self->set_title ($title);

	$self->set_title_data ({
		chunk_cnt     => $title->chunk_cnt,
		with_avisplit => $title->with_avisplit,
		with_cleanup  => $title->with_cleanup,
	});

	return $self;
}

sub build {
	my $self = shift; $self->trace_in;

	# build window -----------------------------------------------
	my $win = Gtk::Window->new ( -toplevel );
	$win->set_title($self->config('program_name'). " Edit Cluster Project");
	$win->border_width(0);
	$win->set_uposition (10,10);
	$win->realize;

	$self->set_gtk_widgets ({});

	# Build dialog -----------------------------------------------
	my $dialog_vbox = Gtk::VBox->new;
	$dialog_vbox->show;
	$dialog_vbox->set_border_width(10);
	$win->add($dialog_vbox);

	my ($frame, $vbox, $hbox, $button);

	# Edite Title Attributes --------------------------------------
	$frame = Gtk::Frame->new ("Edit Project Attributes");
	$frame->show;
	$dialog_vbox->pack_start($frame, 0, 1, 0);
	$vbox = Gtk::VBox->new;
	$vbox->set_border_width(5);
	$vbox->show;
	$frame->add ($vbox);

	my $title = $self->title;
	my $title_data = $self->title_data;

	my @fields = (
		{
			label => "Project",
			type => "string",
			value => $title->project->label,
			readonly => 1,
			
		},
		{
			label => "Number of chunks",
			type => "string",
			value => $title->chunk_cnt,
			width => 80,
			onchange => sub {
				$title_data->{chunk_cnt} = $_[0]->get_text;
			},
			readonly => ($title->project->state ne 'not scheduled'),
			
		},
		{
			label => "Do avisplit after transcoding?",
			type => "switch",
			value => $title->with_avisplit,
			onchange => sub {
				$title_data->{with_avisplit} = $_[0];
			},
			readonly => ($title->project->state eq 'finished'),
		},
		{
			label => "Cleanup temp. AVI chunk files after merging?",
			type => "switch",
			value => $title->with_cleanup,
			onchange => sub {
				$title_data->{with_cleanup} = $_[0];
			},
			readonly => ($title->project->state eq 'finished' or
				     $title->project->state eq 'audio processing' or
				     $title->project->state eq 'merged' ),
		},
	);

	my $table = $self->create_dialog ( @fields );
	$vbox->pack_start ($table, 0, 1, 0);

	$hbox = Gtk::HBox->new;
	$hbox->show;
	$vbox->pack_start ($hbox, 0, 1, 0);

	$button = Gtk::Button->new_with_label ("      Ok      ");
	$button->show;
	$button->signal_connect ( "clicked", sub { $self->dialog_ok } );

	$hbox->pack_start ($button, 0, 1, 0);

	$button = Gtk::Button->new_with_label ("    Cancel    ");
	$button->show;
	$button->signal_connect ( "clicked", sub { $self->dialog_cancel } );
	$hbox->pack_start ($button, 0, 1, 0);

	# Register component and window ------------------------------
	$self->set_widget($win);
	$self->set_gtk_window_widget($win);

	$win->show;

	return 1;
}

sub dialog_ok {
	my $self = shift;

	my $title = $self->title;

	# copy data into title object
	my ($k, $v);
	my $set_method;

	while ( ($k, $v) = each %{$self->title_data} ) {
		$set_method = "set_".$k;
		$title->$set_method ($v) if $v ne $title->$k ();
	}

	# save changes
	$title->save;

	$self->gtk_window_widget->destroy;

	1;
}

sub dialog_cancel {
	my $self = shift;
	
	$self->gtk_window_widget->destroy;
	
	1;
}

1;
